**To delete a TagOption**

The following ``delete-tag-option`` example deletes the specified TagOption. ::

    aws servicecatalog delete-tag-option \
        --id tag-iabcdn4fzjjms

This command produces no output.
